@@ -33,7 +33,9 @@ struct _GsPluginJob
 	GsPluginRefreshFlags	 refresh_flags;
 	GsPluginFailureFlags	 failure_flags;
 	guint			 max_results;
+	guint			 timeout;
 	guint64			 age;
+	GsPlugin		*plugin;
 	GsPluginAction		 action;
 	GsAppListSortFunc	 sort_func;
 	gpointer		 sort_func_data;
@@ -45,6 +47,7 @@ struct _GsPluginJob
 	GsCategory		*category;
 	AsReview		*review;
 	GsPrice			*price;
+	gint64			 time_created;
 };
 
 enum {
@@ -63,6 +66,7 @@ enum {
 	PROP_REVIEW,
 	PROP_MAX_RESULTS,
 	PROP_PRICE,
+	PROP_TIMEOUT,
 	PROP_LAST
 };
 
@@ -72,6 +76,7 @@ gchar *
 gs_plugin_job_to_string (GsPluginJob *self)
 {
 	GString *str = g_string_new (NULL);
+	gint64 time_now = g_get_monotonic_time ();
 	g_string_append_printf (str, "running %s",
 				gs_plugin_action_to_string (self->action));
 	if (self->refine_flags > 0) {
@@ -82,6 +87,8 @@ gs_plugin_job_to_string (GsPluginJob *self)
 		g_autofree gchar *tmp = gs_plugin_failure_flags_to_string (self->failure_flags);
 		g_string_append_printf (str, " with failure-flags=%s", tmp);
 	}
+	if (self->timeout > 0)
+		g_string_append_printf (str, " with timeout=%u", self->timeout);
 	if (self->age != 0) {
 		if (self->age == G_MAXUINT) {
 			g_string_append (str, " with cache age=any");
@@ -121,6 +128,10 @@ gs_plugin_job_to_string (GsPluginJob *self)
 		g_autofree gchar *path = g_file_get_path (self->file);
 		g_string_append_printf (str, " with file=%s", path);
 	}
+	if (self->plugin != NULL) {
+		g_string_append_printf (str, " on plugin=%s",
+					gs_plugin_get_name (self->plugin));
+	}
 	if (self->list != NULL && gs_app_list_length (self->list) > 0) {
 		g_autofree const gchar **unique_ids = NULL;
 		g_autofree gchar *unique_ids_str = NULL;
@@ -132,6 +143,10 @@ gs_plugin_job_to_string (GsPluginJob *self)
 		unique_ids_str = g_strjoinv (",", (gchar**) unique_ids);
 		g_string_append_printf (str, " on apps %s", unique_ids_str);
 	}
+	if (time_now - self->time_created > 1000) {
+		g_string_append_printf (str, " took %" G_GINT64_FORMAT "ms",
+					(time_now - self->time_created) / 1000);
+	}
 	return g_string_free (str, FALSE);
 }
 
@@ -212,6 +227,20 @@ gs_plugin_job_get_max_results (GsPluginJob *self)
 	return self->max_results;
 }
 
+void
+gs_plugin_job_set_timeout (GsPluginJob *self, guint timeout)
+{
+	g_return_if_fail (GS_IS_PLUGIN_JOB (self));
+	self->timeout = timeout;
+}
+
+guint
+gs_plugin_job_get_timeout (GsPluginJob *self)
+{
+	g_return_val_if_fail (GS_IS_PLUGIN_JOB (self), 0);
+	return self->timeout;
+}
+
 void
 gs_plugin_job_set_age (GsPluginJob *self, guint64 age)
 {
@@ -345,6 +374,20 @@ gs_plugin_job_get_file (GsPluginJob *self)
 	return self->file;
 }
 
+void
+gs_plugin_job_set_plugin (GsPluginJob *self, GsPlugin *plugin)
+{
+	g_return_if_fail (GS_IS_PLUGIN_JOB (self));
+	g_set_object (&self->plugin, plugin);
+}
+
+GsPlugin *
+gs_plugin_job_get_plugin (GsPluginJob *self)
+{
+	g_return_val_if_fail (GS_IS_PLUGIN_JOB (self), NULL);
+	return self->plugin;
+}
+
 void
 gs_plugin_job_set_category (GsPluginJob *self, GsCategory *category)
 {
@@ -435,6 +478,9 @@ gs_plugin_job_get_property (GObject *obj, guint prop_id, GValue *value, GParamSp
 	case PROP_MAX_RESULTS:
 		g_value_set_uint (value, self->max_results);
 		break;
+	case PROP_TIMEOUT:
+		g_value_set_uint (value, self->timeout);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, prop_id, pspec);
 		break;
@@ -486,6 +532,9 @@ gs_plugin_job_set_property (GObject *obj, guint prop_id, const GValue *value, GP
 	case PROP_MAX_RESULTS:
 		gs_plugin_job_set_max_results (self, g_value_get_uint (value));
 		break;
+	case PROP_TIMEOUT:
+		gs_plugin_job_set_timeout (self, g_value_get_uint (value));
+		break;
 	case PROP_PRICE:
 		gs_plugin_job_set_price (self, g_value_get_object (value));
 		break;
@@ -504,6 +553,7 @@ gs_plugin_job_finalize (GObject *obj)
 	g_clear_object (&self->app);
 	g_clear_object (&self->list);
 	g_clear_object (&self->file);
+	g_clear_object (&self->plugin);
 	g_clear_object (&self->category);
 	g_clear_object (&self->review);
 	g_clear_object (&self->price);
@@ -586,6 +636,11 @@ gs_plugin_job_class_init (GsPluginJobClass *klass)
 				   G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_MAX_RESULTS, pspec);
 
+	pspec = g_param_spec_uint ("timeout", NULL, NULL,
+				   0, G_MAXUINT, 60,
+				   G_PARAM_READWRITE | G_PARAM_CONSTRUCT);
+	g_object_class_install_property (object_class, PROP_TIMEOUT, pspec);
+
 	pspec = g_param_spec_object ("price", NULL, NULL,
 				     GS_TYPE_PRICE,
 				     G_PARAM_READWRITE);
@@ -599,6 +654,7 @@ gs_plugin_job_init (GsPluginJob *self)
 	self->refine_flags = GS_PLUGIN_REFINE_FLAGS_DEFAULT;
 	self->refresh_flags = GS_PLUGIN_REFRESH_FLAGS_NONE;
 	self->list = gs_app_list_new ();
+	self->time_created = g_get_monotonic_time ();
 }
 
 /* vim: set noexpandtab: */
