@@ -37,9 +37,10 @@ G_BEGIN_DECLS
  * The cache flags.
  **/
 typedef enum {
-	GS_UTILS_CACHE_FLAG_NONE	= 0,
-	GS_UTILS_CACHE_FLAG_WRITEABLE	= 1 << 0,
-	GS_UTILS_CACHE_FLAG_USE_HASH	= 1 << 1,
+	GS_UTILS_CACHE_FLAG_NONE		= 0,
+	GS_UTILS_CACHE_FLAG_WRITEABLE		= 1 << 0,
+	GS_UTILS_CACHE_FLAG_USE_HASH		= 1 << 1,
+	GS_UTILS_CACHE_FLAG_ENSURE_EMPTY	= 1 << 2,
 	/*< private >*/
 	GS_UTILS_CACHE_FLAG_LAST
 } GsUtilsCacheFlags;
@@ -84,6 +85,10 @@ gboolean	 gs_utils_error_convert_appstream (GError	**perror);
 gchar		*gs_utils_get_url_scheme	(const gchar	*url);
 gchar		*gs_utils_get_url_path		(const gchar	*url);
 const gchar	*gs_user_agent			(void);
+void		 gs_utils_append_key_value	(GString	*str,
+						 gsize		 align_len,
+						 const gchar	*key,
+						 const gchar	*value);
 
 G_END_DECLS
 
