@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2013-2016 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2013-2017 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -45,6 +45,7 @@ typedef struct
 	gint			 action_cnt;
 	gboolean		 loading_featured;
 	gboolean		 loading_popular;
+	gboolean		 loading_recent;
 	gboolean		 loading_popular_rotating;
 	gboolean		 loading_categories;
 	gboolean		 empty;
@@ -57,11 +58,13 @@ typedef struct
 	GtkWidget		*bin_featured;
 	GtkWidget		*box_overview;
 	GtkWidget		*box_popular;
+	GtkWidget		*box_recent;
 	GtkWidget		*featured_heading;
 	GtkWidget		*category_heading;
 	GtkWidget		*flowbox_categories;
 	GtkWidget		*flowbox_categories2;
 	GtkWidget		*popular_heading;
+	GtkWidget		*recent_heading;
 	GtkWidget		*scrolledwindow_overview;
 	GtkWidget		*stack_overview;
 	GtkWidget		*categories_expander_button_down;
@@ -141,6 +144,7 @@ gs_overview_page_decrement_action_cnt (GsOverviewPage *self)
 	priv->loading_categories = FALSE;
 	priv->loading_featured = FALSE;
 	priv->loading_popular = FALSE;
+	priv->loading_recent = FALSE;
 	priv->loading_popular_rotating = FALSE;
 
 	/* seems a good place */
@@ -162,7 +166,7 @@ gs_overview_page_get_popular_cb (GObject *source_object,
 	g_autoptr(GsAppList) list = NULL;
 
 	/* get popular apps */
-	list = gs_plugin_loader_get_popular_finish (plugin_loader, res, &error);
+	list = gs_plugin_loader_job_process_finish (plugin_loader, res, &error);
 	gtk_widget_set_visible (priv->box_popular, list != NULL);
 	gtk_widget_set_visible (priv->popular_heading, list != NULL);
 	if (list == NULL) {
@@ -190,6 +194,57 @@ out:
 	gs_overview_page_decrement_action_cnt (self);
 }
 
+static void
+gs_overview_page_get_recent_cb (GObject *source_object, GAsyncResult *res, gpointer user_data)
+{
+	GsOverviewPage *self = GS_OVERVIEW_PAGE (user_data);
+	GsOverviewPagePrivate *priv = gs_overview_page_get_instance_private (self);
+	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (source_object);
+	guint i;
+	GsApp *app;
+	GtkWidget *tile;
+	g_autoptr(GError) error = NULL;
+	g_autoptr(GsAppList) list = NULL;
+
+	/* get recent apps */
+	list = gs_plugin_loader_job_process_finish (plugin_loader, res, &error);
+	if (list == NULL) {
+		if (!g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED))
+			g_warning ("failed to get recent apps: %s", error->message);
+		goto out;
+	}
+
+	/* not enough to show */
+	if (gs_app_list_length (list) < 6) {
+		g_warning ("Only %u apps for recent list, hiding",
+			   gs_app_list_length (list));
+		gtk_widget_set_visible (priv->box_recent, FALSE);
+		gtk_widget_set_visible (priv->recent_heading, FALSE);
+		goto out;
+	}
+
+	/* Don't show apps from the category that's currently featured as the category of the day */
+	gs_app_list_filter (list, filter_category, priv->category_of_day);
+	gs_app_list_randomize (list);
+
+	gs_container_remove_all (GTK_CONTAINER (priv->box_recent));
+
+	for (i = 0; i < gs_app_list_length (list) && i < N_TILES; i++) {
+		app = gs_app_list_index (list, i);
+		tile = gs_popular_tile_new (app);
+		g_signal_connect (tile, "clicked",
+			  G_CALLBACK (app_tile_clicked), self);
+		gtk_container_add (GTK_CONTAINER (priv->box_recent), tile);
+	}
+	gtk_widget_set_visible (priv->box_recent, TRUE);
+	gtk_widget_set_visible (priv->recent_heading, TRUE);
+
+	priv->empty = FALSE;
+
+out:
+	gs_overview_page_decrement_action_cnt (self);
+}
+
 static void
 gs_overview_page_category_more_cb (GtkButton *button, GsOverviewPage *self)
 {
@@ -226,7 +281,7 @@ gs_overview_page_get_category_apps_cb (GObject *source_object,
 	g_autoptr(GsAppList) list = NULL;
 
 	/* get popular apps */
-	list = gs_plugin_loader_get_category_apps_finish (plugin_loader, res, &error);
+	list = gs_plugin_loader_job_process_finish (plugin_loader, res, &error);
 	if (list == NULL) {
 		if (g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED))
 			goto out;
@@ -309,7 +364,7 @@ gs_overview_page_get_featured_cb (GObject *source_object,
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GsAppList) list = NULL;
 
-	list = gs_plugin_loader_get_featured_finish (plugin_loader, res, &error);
+	list = gs_plugin_loader_job_process_finish (plugin_loader, res, &error);
 	if (g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED))
 		goto out;
 
@@ -375,7 +430,7 @@ gs_overview_page_get_categories_cb (GObject *source_object,
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GPtrArray) list = NULL;
 
-	list = gs_plugin_loader_get_categories_finish (plugin_loader, res, &error);
+	list = gs_plugin_loader_job_get_categories_finish (plugin_loader, res, &error);
 	if (list == NULL) {
 		if (!g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED))
 			g_warning ("failed to get categories: %s", error->message);
@@ -489,28 +544,59 @@ gs_overview_page_load (GsOverviewPage *self)
 	priv->empty = TRUE;
 
 	if (!priv->loading_featured) {
+		g_autoptr(GsPluginJob) plugin_job = NULL;
+
 		priv->loading_featured = TRUE;
-		gs_plugin_loader_get_featured_async (priv->plugin_loader,
-						     GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
-						     GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
-						     priv->cancellable,
-						     gs_overview_page_get_featured_cb,
-						     self);
+		plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_FEATURED,
+						 "max-results", 5,
+						 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+						 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
+						 NULL);
+		gs_plugin_loader_job_process_async (priv->plugin_loader,
+						    plugin_job,
+						    priv->cancellable,
+						    gs_overview_page_get_featured_cb,
+						    self);
 		priv->action_cnt++;
 	}
 
 	if (!priv->loading_popular) {
+		g_autoptr(GsPluginJob) plugin_job = NULL;
+
 		priv->loading_popular = TRUE;
-		gs_plugin_loader_get_popular_async (priv->plugin_loader,
-						    GS_PLUGIN_REFINE_FLAGS_REQUIRE_REVIEW_RATINGS |
-						    GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
-						    GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+		plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_POPULAR,
+						 "max-results", 20,
+						 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+						 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
+								 GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
+						 NULL);
+		gs_plugin_loader_job_process_async (priv->plugin_loader,
+						    plugin_job,
 						    priv->cancellable,
 						    gs_overview_page_get_popular_cb,
 						    self);
 		priv->action_cnt++;
 	}
 
+	if (!priv->loading_recent) {
+		g_autoptr(GsPluginJob) plugin_job = NULL;
+
+		priv->loading_recent = TRUE;
+		plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_RECENT,
+						 "age", 60 * 60 * 24 * 60,
+						 "max-results", 20,
+						 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+						 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
+								 GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
+						 NULL);
+		gs_plugin_loader_job_process_async (priv->plugin_loader,
+						    plugin_job,
+						    priv->cancellable,
+						    gs_overview_page_get_recent_cb,
+						    self);
+		priv->action_cnt++;
+	}
+
 	if (!priv->loading_popular_rotating) {
 		const guint MAX_CATS = 2;
 		g_autoptr(GPtrArray) cats_random = NULL;
@@ -522,6 +608,7 @@ gs_overview_page_load (GsOverviewPage *self)
 			const gchar *cat_id;
 			g_autoptr(GsCategory) category = NULL;
 			g_autoptr(GsCategory) featured_category = NULL;
+			g_autoptr(GsPluginJob) plugin_job = NULL;
 
 			cat_id = g_ptr_array_index (cats_random, i);
 			if (i == 0) {
@@ -536,27 +623,33 @@ gs_overview_page_load (GsOverviewPage *self)
 			load_data->category = g_object_ref (category);
 			load_data->self = g_object_ref (self);
 			load_data->title = gs_overview_page_get_category_label (cat_id);
-			gs_plugin_loader_get_category_apps_async (priv->plugin_loader,
-								  featured_category,
-								  GS_PLUGIN_REFINE_FLAGS_REQUIRE_REVIEW_RATINGS |
-								  GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
-								  GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
-								  priv->cancellable,
-								  gs_overview_page_get_category_apps_cb,
-								  load_data);
+			plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_CATEGORY_APPS,
+							 "max-results", 20,
+							 "category", featured_category,
+							 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+							 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
+									 GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
+							 NULL);
+			gs_plugin_loader_job_process_async (priv->plugin_loader,
+							    plugin_job,
+							    priv->cancellable,
+							    gs_overview_page_get_category_apps_cb,
+							    load_data);
 			priv->action_cnt++;
 		}
 		priv->loading_popular_rotating = TRUE;
 	}
 
 	if (!priv->loading_categories) {
+		g_autoptr(GsPluginJob) plugin_job = NULL;
 		priv->loading_categories = TRUE;
-		gs_plugin_loader_get_categories_async (priv->plugin_loader,
-						       GS_PLUGIN_REFINE_FLAGS_DEFAULT,
-						       GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
-						       priv->cancellable,
-						       gs_overview_page_get_categories_cb,
-						       self);
+		plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_CATEGORIES,
+						 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+						 NULL);
+		gs_plugin_loader_job_get_categories_async (priv->plugin_loader, plugin_job,
+							  priv->cancellable,
+							  gs_overview_page_get_categories_cb,
+							  self);
 		priv->action_cnt++;
 	}
 }
@@ -648,7 +741,7 @@ gs_overview_page_get_sources_cb (GsPluginLoader *plugin_loader,
 	GsOverviewPagePrivate *priv = gs_overview_page_get_instance_private (self);
 
 	/* get the results */
-	list = gs_plugin_loader_get_sources_finish (plugin_loader, res, &error);
+	list = gs_plugin_loader_job_process_finish (plugin_loader, res, &error);
 	if (list == NULL) {
 		if (g_error_matches (error,
 				     GS_PLUGIN_ERROR,
@@ -695,9 +788,14 @@ static void
 gs_overview_page_rescan_proprietary_sources (GsOverviewPage *self)
 {
 	GsOverviewPagePrivate *priv = gs_overview_page_get_instance_private (self);
-	gs_plugin_loader_get_sources_async (priv->plugin_loader,
-					    GS_PLUGIN_REFINE_FLAGS_REQUIRE_SETUP_ACTION,
-					    GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+	g_autoptr(GsPluginJob) plugin_job = NULL;
+
+	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_SOURCES,
+					 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+					 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_SETUP_ACTION,
+					 NULL);
+	gs_plugin_loader_job_process_async (priv->plugin_loader,
+					    plugin_job,
 					    priv->cancellable,
 					    (GAsyncReadyCallback) gs_overview_page_get_sources_cb,
 					    self);
@@ -804,6 +902,10 @@ gs_overview_page_setup (GsPage *page,
 		gtk_container_add (GTK_CONTAINER (priv->box_popular), tile);
 	}
 
+	/* hide unless there are enough apps */
+	gtk_widget_set_visible (priv->box_recent, FALSE);
+	gtk_widget_set_visible (priv->recent_heading, FALSE);
+
 	/* handle category expander */
 	g_signal_connect (priv->categories_expander_button_down, "clicked",
 			  G_CALLBACK (gs_overview_page_categories_expander_down_cb), self);
@@ -895,11 +997,13 @@ gs_overview_page_class_init (GsOverviewPageClass *klass)
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, bin_featured);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, box_overview);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, box_popular);
+	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, box_recent);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, category_heading);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, featured_heading);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, flowbox_categories);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, flowbox_categories2);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, popular_heading);
+	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, recent_heading);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, scrolledwindow_overview);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, stack_overview);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, categories_expander_button_down);
